==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ms/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Sahkan Pemutihan Aset Pukal',
  'bulk_delete_help'	=> 'Semak aset untuk penghapusan pukal di bawah. Sebaik sahaja dipadam, aset ini dapat dipulihkan, tetapi mereka tidak lagi akan dikaitkan dengan mana-mana pengguna yang mereka buat sekarang.',
  'bulk_delete_warn'	=> 'Anda akan hapus: asset_count aset.',
	'bulk_update'		=> 'Aset Kemas Kini Pukal',
	'bulk_update_help'	=> 'Borang ini membolehkan anda mengemas kini berbilang aset sekaligus. Hanya isikan medan yang perlu anda ubah. Mana-mana medan yang dibiarkan kosong akan kekal tidak berubah.',
	'bulk_update_warn'	=> 'Anda akan menyunting sifat aset aset_count.',
    'checkedout_to'		=> 'Agihkan Kepada',
    'checkout_date'		=> 'Tarikh Checkout',
    'checkin_date'		=> 'Tarikh daftar masuk',
    'checkout_to'		=> 'Agihkan kepada',
    'cost'				=> 'Harga Pembelian',
    'create'			=> 'Cipta Harta',
    'date'				=> 'Tarikh Pembelian',
    'depreciation'	    => 'Susut nilai',
    'depreciates_on'	=> 'Susut Nilai Pada',
    'default_location'	=> 'Lokasi Asal',
    'eol_date'			=> 'Tarikh EOL',
    'eol_rate'			=> 'Kadar EOL',
    'expected_checkin'  => 'Tarikh Periksa Yang Diharapkan',
    'expires'			=> 'Luput',
    'fully_depreciated'	=> 'Susut Nilai Penuh',
    'help_checkout'		=> 'Jika anda ingin memberikan aset ini dengan segera, pilih "Sedia Digelar" dari senarai status di atas.',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Pengeluar',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Harta',
    'notes'				=> 'Nota',
    'order'				=> 'Nombor Pesanan',
    'qr'				=> 'Kod QR',
    'requestable'		=> 'Pengguna dibenarkan untuk memohon harta ini',
    'select_statustype'	=> 'Pilih Jenis Status',
    'serial'			=> 'Siri',
    'status'			=> 'Status',
    'tag'				=> 'Tag Harta',
    'update'			=> 'Kemaskini Harta',
    'warranty'			=> 'Waranti',
		'warranty_expires'		=> 'Tamat Tempoh Waranti',
    'years'				=> 'tahun',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ms/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Sahkan Pemutihan Aset Pukal',
  'bulk_delete_help'	=> 'Semak aset untuk penghapusan pukal di bawah. Sebaik sahaja dipadam, aset ini dapat dipulihkan, tetapi mereka tidak lagi akan dikaitkan dengan mana-mana pengguna yang mereka buat sekarang.',
  'bulk_delete_warn'	=> 'Anda akan hapus: asset_count aset.',
    'bulk_update'		=> 'Aset Kemas Kini Pukal',
    'bulk_update_help'	=> 'Borang ini membolehkan anda mengemas kini berbilang aset sekaligus. Hanya isikan medan yang perlu anda ubah. Mana-mana medan yang dibiarkan kosong akan kekal tidak berubah.',
    'bulk_update_warn'	=> 'Anda akan menyunting sifat aset aset_count.',
    'checkedout_to'		=> 'Agihkan Kepada',
    'checkout_date'		=> 'Tarikh Checkout',
    'checkin_date'		=> 'Tarikh daftar masuk',
    'checkout_to'		=> 'Agihkan kepada',
    'cost'				=> 'Harga Pembelian',
    'create'			=> 'Cipta Harta',
    'date'				=> 'Tarikh Pembelian',
    'depreciation'	    => 'Susut nilai',
    'depreciates_on'	=> 'Susut Nilai Pada',
    'default_location'	=> 'Lokasi Asal',
    'eol_date'			=> 'Tarikh EOL',
    'eol_rate'			=> 'Kadar EOL',
    'expected_checkin'  => 'Tarikh Periksa Yang Diharapkan',
    'expires'			=> 'Luput',
    'fully_depreciated'	=> 'Susut Nilai Penuh',
    'help_checkout'		=> 'Jika anda ingin memberikan aset ini dengan segera, pilih "Sedia Digelar" dari senarai status di atas.',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Pengeluar',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Harta',
    'notes'				=> 'Nota',
    'order'				=> 'Nombor Pesanan',
    'qr'				=> 'Kod QR',
    'requestable'		=> 'Pengguna dibenarkan untuk memohon harta ini',
    'select_statustype'	=> 'Pilih Jenis Status',
    'serial'			=> 'Siri',
    'status'			=> 'Status',
    'tag'				=> 'Tag Harta',
    'update'			=> 'Kemaskini Harta',
    'warranty'			=> 'Waranti',
        'warranty_expires'		=> 'Tamat Tempoh Waranti',
    'years'				=> 'tahun',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
